class Meta:
    """App Information"""

    __title__ = "ciscotmg"
    __description__ = "Private Python SDK for Cisco TMG APIs"
    __url__ = "https://github.com/robertcsapo/ciscotmg"
    __download_url__ = "https://pypi.python.org/pypi/ciscotmg"
    __author__ = "Robert Csapo"
    __email__ = "rcsapo@cisco.com"
    __copyright__ = "Copyright (c) 2022 Cisco Systems, Inc."
    __license__ = "MIT"
    __version__ = "0.2.9"
